@@ -1,3 +1,8 @@
+from .common.config import (
+    updateCachingMaxGBs,
+    updateCachingMaxSize
+)
+
 from .common.python_routines import (
     eTo10,
     print_status,
@@ -28,4 +33,3 @@ from .common.profile_classes import (
     DensProfsHDF5,
     DensShapeProfsHDF5
 )
-
